You are viewing a plain text version of this content. The canonical link for it is here.
Posted to derby-commits@db.apache.org by dj...@apache.org on 2008/02/18 19:01:48 UTC

svn commit: r628836 - in /db/derby/code/trunk/java/engine/org/apache/derby: iapi/services/jmx/ManagementService.java impl/services/jmx/JMXManagementService.java impl/services/jmxnone/NoManagementService.java

Author: djd
Date: Mon Feb 18 10:01:45 2008
New Revision: 628836

URL: http://svn.apache.org/viewvc?rev=628836&view=rev
Log:
DERBY-1387 Cleanup some details of the ManagementService api based upon feedback from John Embretsen. Mainly rename 'nameAttributes' to 'keyProperties' to match JMX terminology

Modified:
    db/derby/code/trunk/java/engine/org/apache/derby/iapi/services/jmx/ManagementService.java
    db/derby/code/trunk/java/engine/org/apache/derby/impl/services/jmx/JMXManagementService.java
    db/derby/code/trunk/java/engine/org/apache/derby/impl/services/jmxnone/NoManagementService.java

Modified: db/derby/code/trunk/java/engine/org/apache/derby/iapi/services/jmx/ManagementService.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/iapi/services/jmx/ManagementService.java?rev=628836&r1=628835&r2=628836&view=diff
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/services/jmx/JMXManagementService.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/services/jmx/JMXManagementService.java Mon Feb 18 10:01:45 2008
@@ -171,23 +171,23 @@
      * of Derby's mbeans to be hidden from JMX, thus only exposing
      * the MBean's interface in org.apache.derby.mbeans.
      * 
-     * The object name instance 
-     * represented by the given String will be created by this method.
      * 
      * @param bean The MBean to wrap with a StandardMBean and register
      * @param beanInterface The management interface for the MBean.
-     * @param nameAttributes The String representation of the MBean's attrributes,
-     * they will be added into the ObjectName with Derby's domain
+     * @param keyProperties The String representation of the MBean's key properties,
+     * they will be added into the ObjectName with Derby's domain. Key
+     * type should be first with a short name for the bean, typically the
+     * class name without the package.
      * 
      */
     public synchronized Object registerMBean(final Object bean,
             final Class beanInterface,
-            final String nameAttributes)
+            final String keyProperties)
             throws StandardException {
 
         try {
             final ObjectName beanName = new ObjectName(
-                    DERBY_JMX_DOMAIN + ":" + nameAttributes);
+                    DERBY_JMX_DOMAIN + ":" + keyProperties);
             final StandardMBean standardMBean =
                 new StandardMBean(bean, beanInterface);
             

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/services/jmxnone/NoManagementService.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/services/jmxnone/NoManagementService.java?rev=628836&r1=628835&r2=628836&view=diff
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/services/jmxnone/NoManagementService.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/services/jmxnone/NoManagementService.java Mon Feb 18 10:01:45 2008
@@ -28,7 +28,7 @@
     }
     public Object registerMBean(final Object bean,
             final Class beanInterface,
-            final String nameAttributes)
+            final String keyProperties)
     {
         return null;
     }
--- db/derby/code/trunk/java/engine/org/apache/derby/iapi/services/jmx/ManagementService.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/iapi/services/jmx/ManagementService.java Mon Feb 18 10:01:45 2008
@@ -47,14 +47,12 @@
     
     /**
      * Registers an MBean with the MBean server.
-     * The object name instance 
-     * represented by the given String will be created by this method.
-     * The mbean will be unregistered automatically when Derby shutsdown.
+     * The mbean will be unregistered automatically when Derby shuts down.
      * 
      * @param bean The MBean to wrap with a StandardMBean and register
      * @param beanInterface The management interface for the MBean.
      * @param nameAttributes The String representation of the MBean's attrributes,
      * they will be added into the ObjectName with Derby's domain. Attribute
      * type should be first with a short name for the bean, typically the
      * class name without the package.
      * 
@@ -62,7 +60,7 @@
      */
     public Object registerMBean(Object bean,
             Class beanInterface,
-            String nameAttributes)
+            String keyProperties)
             throws StandardException;
     
     /**
@@ -47,14 +47,12 @@
      * @param bean The MBean to wrap with a StandardMBean and register
      * @param beanInterface The management interface for the MBean.
-     * @param nameAttributes The String representation of the MBean's attrributes,
-     * they will be added into the ObjectName with Derby's domain. Attribute
+     * @param keyProperties The String representation of the MBean's key properties,
+     * they will be added into the ObjectName with Derby's domain. Key
      * type should be first with a short name for the bean, typically the
      * class name without the package.

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/services/jmx/JMXManagementService.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/services/jmx/JMXManagementService.java?rev=628836&r1=628835&r2=628836&view=diff
==============================================================================